ML Insights
===========

Package to understand ML Models

Installation:
-------------

.. code-block:: bash

    $ pip install ml_insights


Usage:
------

.. code-block:: python

    >>> import ml_insights as mli
    >>> xray = mli.ModelXRay(model, data)


Examples:
---------

`Notebook Examples and Useage <examples/>`_


Documentation:
--------------

https://ml-insights.readthedocs.io.

Source:
-------

https://github.com/numeristical/introspective.

License:
--------

Free software: `MIT license <LICENSE>`_

Developed By:
------------

* Brian Lucena
* Ramesh Sampath

References
--------

Alex Goldstein, Adam Kapelner, Justin Bleich, and Emil Pitkin. 2014. Peeking Inside the Black Box: Visualizing Statistical Learning With Plots of Individual Conditional Expectation. Journal of Computational and Graphical Statistics (March 2014)
